@@ -7,19 +7,14 @@ This module provides tools for creating MySQL users and databases.
 """
 from __future__ import with_statement
 
-from fabric.api import env, hide, prompt, puts, run, settings
+from pipes import quote
+
+from fabric.api import env, hide, puts, run, settings
 
 from fabtools.utils import run_as_root
 
 
-def prompt_password(user='root'):
-    """
-    Ask MySQL password interactively.
-    """
-    return prompt('Please enter password for MySQL user "%s":' % user)
-
-
-def _query(query, use_sudo=True, **kwargs):
+def query(query, use_sudo=True, **kwargs):
     """
     Run a MySQL query.
     """
@@ -27,13 +22,21 @@ def _query(query, use_sudo=True, **kwargs):
 
     user = kwargs.get('mysql_user') or env.get('mysql_user')
     password = kwargs.get('mysql_password') or env.get('mysql_password')
-    if user and not password:
-        password = prompt_password(user)
 
-    return func("mysql --batch --raw --skip-column-names --user=%(user)s --password='%(password)s' --execute=\"%(query)s\"" % {
-        'user': user,
-        'password': password,
-        'query': query
+    options = [
+        '--batch',
+        '--raw',
+        '--skip-column-names',
+    ]
+    if user:
+        options.append('--user=%s' % quote(user))
+    if password:
+        options.append('--password=%s' % quote(password))
+    options = ' '.join(options)
+
+    return func('mysql %(options)s --execute=%(query)s' % {
+        'options': options,
+        'query': quote(query),
     })
 
 
@@ -42,7 +45,7 @@ def user_exists(name, host='localhost', **kwargs):
     Check if a MySQL user exists.
     """
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
-        res = _query("""
+        res = query("""
             use mysql;
             SELECT COUNT(*) FROM user
                 WHERE User = '%(name)s' AND Host = '%(host)s';
@@ -67,7 +70,7 @@ def create_user(name, password, host='localhost', **kwargs):
 
     """
     with settings(hide('running')):
-        _query("CREATE USER '%(name)s'@'%(host)s' IDENTIFIED BY '%(password)s';" % {
+        query("CREATE USER '%(name)s'@'%(host)s' IDENTIFIED BY '%(password)s';" % {
             'name': name,
             'password': password,
             'host': host
@@ -80,7 +83,7 @@ def database_exists(name, **kwargs):
     Check if a MySQL database exists.
     """
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
-        res = _query("SHOW DATABASES LIKE '%(name)s';" % {
+        res = query("SHOW DATABASES LIKE '%(name)s';" % {
             'name': name
         }, **kwargs)
 
@@ -103,14 +106,14 @@ def create_database(name, owner=None, owner_host='localhost', charset='utf8',
     """
     with settings(hide('running')):
 
-        _query("CREATE DATABASE %(name)s CHARACTER SET %(charset)s COLLATE %(collate)s;" % {
+        query("CREATE DATABASE %(name)s CHARACTER SET %(charset)s COLLATE %(collate)s;" % {
             'name': name,
             'charset': charset,
             'collate': collate
         }, **kwargs)
 
         if owner:
-            _query("GRANT ALL PRIVILEGES ON %(name)s.* TO '%(owner)s'@'%(owner_host)s' WITH GRANT OPTION;" % {
+            query("GRANT ALL PRIVILEGES ON %(name)s.* TO '%(owner)s'@'%(owner_host)s' WITH GRANT OPTION;" % {
                 'name': name,
                 'owner': owner,
                 'owner_host': owner_host
