@@ -4,7 +4,7 @@ Network
 """
 from __future__ import with_statement
 
-from fabric.api import hide, run, settings
+from fabric.api import hide, run, settings, sudo
 from fabtools.files import is_file
 
 
@@ -16,7 +16,7 @@ def interfaces():
         if is_file('/usr/sbin/dladm'):
             res = run('/usr/sbin/dladm show-link')
         else:
-            res = run('/sbin/ifconfig -s')
+            res = sudo('/sbin/ifconfig -s')
     return map(lambda line: line.split(' ')[0], res.splitlines()[1:])
 
 
@@ -34,7 +34,7 @@ def address(interface):
 
     """
     with settings(hide('running', 'stdout')):
-        res = run("/sbin/ifconfig %(interface)s | grep 'inet '" % locals())
+        res = sudo("/sbin/ifconfig %(interface)s | grep 'inet '" % locals())
     if 'addr' in res:
         return res.split()[1].split(':')[1]
     else:
