@@ -7,7 +7,7 @@ This module provides tools for creating PostgreSQL users and databases.
 """
 from __future__ import with_statement
 
-from fabric.api import cd, hide, run, settings
+from fabric.api import cd, hide, sudo, settings
 
 
 def _run_as_pg(command):
@@ -15,14 +15,15 @@ def _run_as_pg(command):
     Run command as 'postgres' user
     """
     with cd('~postgres'):
-        return run('sudo -u postgres %s' % command)
+        return sudo(command, user='postgres')
 
 
 def user_exists(name):
     """
     Check if a PostgreSQL user exists.
     """
-    with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
+    with settings(hide('running', 'stdout', 'stderr', 'warnings'),
+                  warn_only=True):
         res = _run_as_pg('''psql -t -A -c "SELECT COUNT(*) FROM pg_user WHERE usename = '%(name)s';"''' % locals())
     return (res == "1")
 
@@ -61,6 +62,22 @@ def create_user(name, password, superuser=False, createdb=False,
     _run_as_pg('''psql -c "CREATE USER %(name)s %(options)s;"''' % locals())
 
 
+def drop_user(name):
+    """
+    Drop a PostgreSQL user.
+
+    Example::
+
+        import fabtools
+
+        # Remove DB user if it exists
+        if fabtools.postgres.user_exists('dbuser'):
+            fabtools.postgres.drop_user('dbuser')
+
+    """
+    _run_as_pg('''psql -c "DROP USER %(name)s;"''' % locals())
+
+
 def database_exists(name):
     """
     Check if a PostgreSQL database exists.
@@ -89,6 +106,22 @@ def create_database(name, owner, template='template0', encoding='UTF8',
                   --lc-collate=%(locale)s %(name)s''' % locals())
 
 
+def drop_database(name):
+    """
+    Delete a PostgreSQL database.
+
+    Example::
+
+        import fabtools
+
+        # Remove DB if it exists
+        if fabtools.postgres.database_exists('myapp'):
+            fabtools.postgres.drop_database('myapp')
+
+    """
+    _run_as_pg('''dropdb %(name)s''' % locals())
+
+
 def create_schema(name, database, owner=None):
     """
     Create a schema within a database.
